@@ -223,7 +223,7 @@ aspell_env_var <- function() {
 }
 
 show_env_vars <- function(env_vars, trailing = TRUE) {
-  cat_line("Setting env vars:", col = "darkgrey")
+  cli::cat_line("Setting env vars:", col = "darkgrey")
   cat_bullet(paste0(format(names(env_vars)), ": ", unname(env_vars)), col = "darkgrey")
   if (trailing) {
     cat_rule(col = "cyan")
